@@ -8,6 +8,8 @@ use Text::Context;
 use HTML::Strip;
 use Data::Page;
 use Data::Dumper;
+use Readonly;
+Readonly my $EMPTY_STRING => '';
 
 =head1 NAME
 
@@ -45,7 +47,8 @@ sub view : Global {
     $stash->{template} ||= 'page/view.tt';
 
     $c->forward('inline_tags');
-    $c->stash->{render} = 'highlight' if $c->req->referer && $c->req->referer =~ /.edit$/;
+    $c->stash->{render} = 'highlight'
+      if $c->req->referer && $c->req->referer =~ /.edit$/;
 
     my ( $path_pages, $proto_pages, $id ) =
       @$stash{qw/ path_pages proto_pages id /};
@@ -66,7 +69,8 @@ sub view : Global {
 
         my $perms = $c->check_permissions( $stash->{'path'}, $user );
         if ( !$perms->{'view'} ) {
-            $stash->{'message'}  = $c->loc('Permission Denied to view x', $page->name);
+            $stash->{'message'} =
+              $c->loc( 'Permission Denied to view x', $page->name );
             $stash->{'template'} = 'message.tt';
             return;
         }
@@ -84,7 +88,8 @@ sub view : Global {
         );
         $stash->{rev} = ( defined $content ? $content->version : undef );
         unless ( $stash->{rev} ) {
-            $stash->{message}  = $c->loc('No such revision for ', $page->name);
+            $stash->{message} =
+              $c->loc( 'No such revision for ', $page->name );
             $stash->{template} = 'message.tt';
         }
     }
@@ -140,7 +145,8 @@ sub search : Global {
     my %results_hash;
     while ( my $hit = $hits->fetch_hit_hashref ) {
         $hit->{path} =~ s/X/\//g;
-        my ($path_pages) = $c->model('DBIC::Page')->path_pages( $hit->{path} );
+        my ($path_pages) =
+          $c->model('DBIC::Page')->path_pages( $hit->{path} );
         my $page = $path_pages->[ @$path_pages - 1 ];
 
         # skip search result depending on permissions
@@ -155,15 +161,37 @@ sub search : Global {
         my $content = $strip->parse( $page->content->formatted($c) );
         $strip->eof;
 
- # FIXME: Bug? Some snippet text doesn't get displayed properly by Text::Context
-        my $snippet = Text::Context->new( $content, split( / /, $real_query ) );
+# FIXME: Bug? Some snippet text doesn't get displayed properly by Text::Context
+        my $snippet =
+          Text::Context->new( $content, split( / /, $real_query ) );
 
         # Convert Kinosearch hit score from decimal to percent.
-        my $score = sprintf( "%.0f", $hit->{score} * 1000 );
+        # my $score = sprintf( "%.0f", $hit->{score} * 1000 );
+
+        # Store goods to be used in search results listing
+        # NOTE: $page->path is '/' for app root,
+        # but $c->request->path is empty for app root.
+        my ( $title_base_nodes, $title_terminal_node );
+        my $link_title =
+          $page->path;
+        if ( $page->path eq '/' ) {
+            $title_base_nodes    = $EMPTY_STRING;
+            $title_terminal_node = '/';
+        }
+        else {
+            ( $title_base_nodes, $title_terminal_node ) =
+              $page->path =~ m{(.*/)(.*)$};
+              $title_base_nodes =~ s{^/}{};
+            $title_base_nodes =~ s{/}{ > }g;
+            $title_terminal_node = ucfirst($title_terminal_node);
+        }
         $results_hash{ $hit->{path} } = {
-            snippet => $snippet->as_html,
-            page    => $page,
-            score   => $score,
+            snippet             => $snippet->as_html,
+            page                => $page,
+            score               => $hit->{score},
+            link_title          => $link_title,
+            title_base_nodes    => $title_base_nodes,
+            title_terminal_node => $title_terminal_node
         };
 
     }
@@ -223,7 +251,7 @@ Tag list for the bottom of page views.
 
 sub inline_tags : Global {
     my ( $self, $c, $highlight ) = @_;
-    $c->stash->{template}  ||= 'page/tags.tt';
+    $c->stash->{template} ||= 'page/tags.tt';
     $c->stash->{highlight} = $highlight;
     my $page = $c->stash->{page};
     if ( $c->user_exists ) {
@@ -253,12 +281,14 @@ sub list : Global {
     $c->stash->{pages}    = [ $page->descendants ];
 
     # FIXME - real data here please
-    $c->stash->{orphans}   = [];
+    $c->stash->{orphans} = [];
     $c->stash->{backlinks} =
       [ $c->model("DBIC::Link")->search( to_page => $page->id ) ];
-    $c->stash->{wanted} = [ $c->model("DBIC::WantedPage")->search({
-            from_page => [ $page->id, map { $_->id } $page->descendants ]
-        }) ];
+    $c->stash->{wanted} = [
+        $c->model("DBIC::WantedPage")->search(
+            { from_page => [ $page->id, map { $_->id } $page->descendants ] }
+        )
+    ];
 }
 
 =head2 recent (.recent)
@@ -372,8 +402,8 @@ Display meta information about the current page.
 
 sub info : Global {
     my ( $self, $c ) = @_;
-    $c->stash->{body_length} = length($c->stash->{page}->content->body);
-    $c->stash->{template} = 'page/info.tt';
+    $c->stash->{body_length} = length( $c->stash->{page}->content->body );
+    $c->stash->{template}    = 'page/info.tt';
 }
 
 =head1 AUTHOR
