@@ -6,8 +6,6 @@ use Text::Textile2;
 use Text::SmartyPants;
 my $textile = Text::Textile2->new( flavor => "xhtml1", charset => 'utf-8' );
 
-sub primary_formatter { 1; }
-
 =head1 NAME
 
 MojoMojo::Formatter::Textile - Texile formatting for your content
@@ -21,6 +19,14 @@ syntax for writing human-friendly formatted text.
 
 =over 4
 
+=item primary_formatter
+
+See also L<MojoMojo::Formatter/primary_formatter>.
+
+=cut
+
+sub primary_formatter { 1; }
+
 =item format_content_order
 
 Format order can be 1-99. The Textile formatter runs on 15
