@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-use base qw/Class::Accessor::Fast MojoMojo::Schema::Base::Result/;
+use base qw/MojoMojo::Schema::Base::Result/;
 
 __PACKAGE__->load_components( "PK::Auto", "Core" );
 __PACKAGE__->table("page");
@@ -30,21 +30,21 @@ __PACKAGE__->add_columns(
 );
 __PACKAGE__->set_primary_key("id");
 __PACKAGE__->add_unique_constraint( "page_unique_child_index", [ "parent", "name" ] );
-__PACKAGE__->has_many( "wantedpages", "WantedPage", { "foreign.from_page" => "self.id" }, );
-__PACKAGE__->belongs_to( "parent", "Page", { id => "parent" } );
-__PACKAGE__->has_many( "children", "Page", { "foreign.parent" => "self.id" } );
-__PACKAGE__->belongs_to( "content", "Content", { page => "id", version => "content_version" },
+__PACKAGE__->has_many( "wantedpages", "MojoMojo::Schema::Result::WantedPage", { "foreign.from_page" => "self.id" }, );
+__PACKAGE__->belongs_to( "parent", "MojoMojo::Schema::Result::Page", { id => "parent" } );
+__PACKAGE__->has_many( "children", "MojoMojo::Schema::Result::Page", { "foreign.parent" => "self.id" } );
+__PACKAGE__->belongs_to( "content", "MojoMojo::Schema::Result::Content", { page => "id", version => "content_version" },
 );
-__PACKAGE__->has_many( "versions", "Content", { "foreign.page" => "self.id" } );
-__PACKAGE__->belongs_to( "page_version", "PageVersion", { page => "id", version => "version" },
+__PACKAGE__->has_many( "versions", "MojoMojo::Schema::Result::Content", { "foreign.page" => "self.id" } );
+__PACKAGE__->belongs_to( "page_version", "MojoMojo::Schema::Result::PageVersion", { page => "id", version => "version" },
 );
-__PACKAGE__->has_many( "tags",       "Tag",  { "foreign.page"      => "self.id" } );
-__PACKAGE__->has_many( "links_from", "Link", { "foreign.from_page" => "self.id" }, );
-__PACKAGE__->has_many( "links_to",   "Link", { "foreign.to_page"   => "self.id" } );
-__PACKAGE__->has_many( "roleprivileges", "RolePrivilege", { "foreign.page"   => "self.id" }, );
-__PACKAGE__->has_many( "attachments",    "Attachment",    { "foreign.page"   => "self.id" },{order_by=>'id desc' } );
-__PACKAGE__->has_many( "comments",       "Comment",       { "foreign.page"   => "self.id" } );
-__PACKAGE__->has_many( "journals",       "Journal",       { "foreign.pageid" => "self.id" } );
+__PACKAGE__->has_many( "tags",       "MojoMojo::Schema::Result::Tag",  { "foreign.page"      => "self.id" } );
+__PACKAGE__->has_many( "links_from", "MojoMojo::Schema::Result::Link", { "foreign.from_page" => "self.id" }, );
+__PACKAGE__->has_many( "links_to",   "MojoMojo::Schema::Result::Link", { "foreign.to_page"   => "self.id" } );
+__PACKAGE__->has_many( "roleprivileges", "MojoMojo::Schema::Result::RolePrivilege", { "foreign.page"   => "self.id" }, );
+__PACKAGE__->has_many( "attachments",    "MojoMojo::Schema::Result::Attachment",    { "foreign.page"   => "self.id" },{order_by=>'id desc' } );
+__PACKAGE__->has_many( "comments",       "MojoMojo::Schema::Result::Comment",       { "foreign.page"   => "self.id" } );
+__PACKAGE__->has_many( "journals",       "MojoMojo::Schema::Result::Journal",       { "foreign.pageid" => "self.id" } );
 
 =head1 NAME
 
