@@ -160,12 +160,17 @@ $( function() {
             $('#taginput').attr('value','')
         }
     })
-    $('#commentlogin').ajaxForm({
+    
+    $('#commentlogin').livequery (function() {
+         $('#commentlogin').ajaxForm({
         target: '#commentLogin',
-    });
-    $('#commentForm').ajaxForm({
-        target: '#comments'
     })
+    });
+    $('#commentForm').livequery(function() {
+         $('#commentForm').ajaxForm({
+            target: '#comments'
+        });
+    });
     $('.tagaction').livequery('click', function() {
        $('#tags').load($(this).attr('href') );
        return false;
